@@ -4,25 +4,23 @@ use warnings;
 no indirect;
 use Object::Pad;
 use Log::Any qw($log);
+use JSON::MaybeXS;
 
-our $VERSION = '0.001';    ## VERSION
+our $VERSION = '0.002';    ## VERSION
 
 class WebService::GrowthBook::FeatureResult {
     field $id    : param : reader;
     field $value : param : reader;
-    field $type  : param : reader;
     method on {
-        if ($type eq 'boolean') {
+        if (JSON::MaybeXS::is_bool($value)) {
             return $value ? 1 : 0;
         }
-        $log->errorf("FeatureResult->on called on non-boolean feature %s", $id);
+        $log->errorf("FeatureResult->on/off called on non-boolean feature %s", $id);
         return undef;
     }
     method off {
-        if ($type eq 'boolean') {
-            return $value ? 0 : 1;
-        }
-        $log->errorf("FeatureResult->off called on non-boolean feature %s", $id);
-        return undef;
+        my $result = $self->on;
+        return $result unless defined($result);
+        return $result ? 0 : 1;
     }
 }
